[![GitHub](https://img.shields.io/github/license/mizarai/mizar)](https://img.shields.io/github/license/mizarai/mizar)
[![PyPi](https://img.shields.io/pypi/v/mizar)](https://img.shields.io/pypi/v/mizar)

# The MizarAI Platform API

Welcome to the MizarAI platform API! This package enables the user to interact
with the [MizarAI](https://mizar.ai) platform.

## Installation

To install the package please run:

```bash
pip install mizar
```

## Mizar

Mizar is building a marketplace for algo-traders to deploy and share their trading strategies with investors. Please visit the website [mizar.ai](https://mizar.ai/) to learn more.

## Links

- Website: [https://mizar.ai/](https://mizar.ai/)
- PyPi Releases: [https://pypi.org/project/mizar/](https://pypi.org/project/mizar/)
- Source Code: [https://github.com/MizarAI/mizar/](https://github.com/MizarAI/mizar/)
